@@ -1,6 +1,6 @@
 /* options.h.in
  *
- * Copyright (C) 2006-2024 wolfSSL Inc.
+ * Copyright (C) 2006-2025 wolfSSL Inc.
  *
  * This file is part of wolfSSL.
  *
@@ -36,7 +36,7 @@ extern "C" {
 #undef _GNU_SOURCE
 /* #undef _GNU_SOURCE */
 #undef _POSIX_THREADS
-#define _POSIX_THREADS
+/* #undef _POSIX_THREADS */
 #endif
 #undef ASIO_USE_WOLFSSL
 /* #undef ASIO_USE_WOLFSSL */
@@ -366,10 +366,10 @@ extern "C" {
 #define NO_DES3_TLS_SUITES
 #undef WOLFSSL_EXPERIMENTAL_SETTINGS
 /* #undef WOLFSSL_EXPERIMENTAL_SETTINGS */
-#undef WOLFSSL_HAVE_KYBER
-/* #undef WOLFSSL_HAVE_KYBER */
-#undef WOLFSSL_WC_KYBER
-/* #undef WOLFSSL_WC_KYBER */
+#undef WOLFSSL_HAVE_MLKEM
+/* #undef WOLFSSL_HAVE_MLKEM */
+#undef WOLFSSL_WC_MLKEM
+/* #undef WOLFSSL_WC_MLKEM */
 #undef NO_WOLFSSL_STUB
 /* #undef NO_WOLFSSL_STUB */
 #undef HAVE_ECC_SECPR2
@@ -382,6 +382,18 @@ extern "C" {
 /* #undef HAVE_ECC_KOBLITZ */
 #undef HAVE_ECC_CDH
 /* #undef HAVE_ECC_CDH */
+#undef WOLFSSL_HAVE_LMS
+/* #undef WOLFSSL_HAVE_LMS */
+#undef WOLFSSL_WC_LMS
+/* #undef WOLFSSL_WC_LMS */
+#undef  WOLFSSL_LMS_SHA256_192
+/* #undef WOLFSSL_LMS_SHA256_192 */
+#undef  WOLFSSL_NO_LMS_SHA256_256
+/* #undef WOLFSSL_NO_LMS_SHA256_256 */
+#undef WOLFSSL_HAVE_XMSS
+/* #undef WOLFSSL_HAVE_XMSS */
+#undef WOLFSSL_WC_XMSS
+/* #undef WOLFSSL_WC_XMSS */
 
 #ifdef __cplusplus
 }
